@@ -40,7 +40,7 @@ from dpys import utils
 RED = 0xD40C00
 BLUE = 0x0000FF
 GREEN = 0x32C12C
-version = "5.1.2"
+version = "5.1.6"
 
 print("We recommend that you read https://jgltechnologies.com/dpys before you use DPYS.")
 
@@ -430,7 +430,7 @@ class mute_on_join:
 
 
 class warnings:
-    class Punishments:
+    class Punishment:
         def __init__(self, punishment: str, duration: typing.Optional[int] = None):
             if punishment.startswith("temp") and duration is None:
                 raise Exception("duration cannot be None for temporary punishments.")
@@ -572,7 +572,7 @@ class warnings:
 
     @staticmethod
     async def punish(inter: MessageCommandInteraction, member: discord.Member, dir: str,
-                     punishments: typing.List[Punishments],
+                     punishments: typing.List[Punishment],
                      add_role: typing.Optional[int] = None, remove_role: typing.Optional[int] = None) -> None:
         await asyncio.get_event_loop().run_in_executor(None, os.chdir, dir)
         memberid = str(member.id)
@@ -603,7 +603,7 @@ class warnings:
                     return
             except:
                 return
-            if punishments[warnings_number - 1].duration is None:
+            if punishments[warnings_number - 1].duration is not None:
                 if punishments[warnings_number - 1].punishment == "temp_ban":
                     time = punishments[warnings_number - 1].duration
                     await member.ban(reason=f"You have received {warnings_number} warnings.")
@@ -675,7 +675,7 @@ class warnings:
                                 await db.execute("DELETE FROM tempmute WHERE guild = ?", (str(guild_id),))
                                 await db.commit()
                                 continue
-                            member = guild.get_member(int(member))
+                            member = guild.get_member(int(member_id))
                             if not isinstance(member, discord.Member):
                                 await db.execute("DELETE FROM tempmute WHERE guild = ? and member = ?",
                                                  (str(guild_id), str(member_id)))
